@@ -23,14 +23,14 @@
 #include <kdpkgdialog.h>
 
 #include <kde_terminal_interface.h>
-#include <kparts/part.h>
+#include <tdeparts/part.h>
 #include <process.h>
 #include <tqprocess.h>
 
 class kdpkg : public KdpkgDialog
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 		kdpkg(const TQString &url = TQString(), TQWidget *parent = 0L, const char *name = 0L, const TQStringList &foo = TQStringList());
